# hosts/valefar/configuration.nix (or default.nix)
{ config, lib, pkgs, modulesPath, ... }:

{
  imports = [
    # Host-specific hardware
    ./hardware.nix
    ./secrets.nix
    
    # Common modules shared across hosts
    ../../modules/common/system.nix
    ../../modules/common/users.nix
    ../../modules/common/services.nix
    
    # Services specific to this host
    ../../services/garage.nix
    ../../services/forgejo.nix

    # Common secrets
    ../../host-secrets.nix
  ];

  # pin host platform & microcode
  nixpkgs.hostPlatform               = lib.mkDefault "x86_64-linux";
  hardware.cpu.intel.updateMicrocode = lib.mkDefault
    config.hardware.enableRedistributableFirmware;

  networking.hostName = "valefar";
  networking.hostId = "2a07da90";
  
  boot.supportedFilesystems = [ "zfs" ];
  boot.kernelModules = [ "nct6775" "coretemp" ];

  environment.systemPackages = with pkgs; [
    lm_sensors
  ];
}
